:mod:`art.attacks.inference.attribute_inference`
================================================
.. automodule:: art.attacks.inference.attribute_inference

Attribute Inference Black-Box
-----------------------------
.. autoclass:: AttributeInferenceBlackBox
   :members:
   :special-members:

Attribute Inference White-Box Lifestyle Decision-Tree
-----------------------------------------------------
.. autoclass:: AttributeInferenceWhiteBoxLifestyleDecisionTree
   :members:
   :special-members:

Attribute Inference White-Box Decision-Tree
-------------------------------------------
.. autoclass:: AttributeInferenceWhiteBoxDecisionTree
   :members:
   :special-members:
